@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-ui.h 5827 2007-08-16 20:39:41Z paolo $
+ * $Id: gedit-ui.h 6754 2008-12-29 18:29:09Z pborelli $
  */
 
 #ifndef __GEDIT_UI_H__
@@ -39,8 +39,6 @@
 
 #include "gedit-commands.h"
 
-#define GEDIT_STOCK_PAGE_SETUP  "document-page-setup"
-
 G_BEGIN_DECLS
 
 static const GtkActionEntry gedit_always_sensitive_menu_entries[] =
@@ -82,7 +80,7 @@ static const GtkActionEntry gedit_menu_entries[] =
 	  N_("Save the current file with a different name"), G_CALLBACK (_gedit_cmd_file_save_as) },
 	{ "FileRevert", GTK_STOCK_REVERT_TO_SAVED, NULL, NULL,
 	  N_("Revert to a saved version of the file"), G_CALLBACK (_gedit_cmd_file_revert) },
-	{ "FilePageSetup", GEDIT_STOCK_PAGE_SETUP, N_("Page Set_up..."), NULL,
+	{ "FilePageSetup", GTK_STOCK_PAGE_SETUP, N_("Page Set_up..."), NULL,
 	  N_("Setup the page settings"), G_CALLBACK (_gedit_cmd_file_page_setup) },
 	{ "FilePrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Previe_w"),"<control><shift>P",
 	  N_("Print preview"), G_CALLBACK (_gedit_cmd_file_print_preview) },
