@@ -37,6 +37,7 @@
 #include "gedit-file-browser-utils.h"
 #include "gedit-file-browser-error.h"
 #include "gedit-file-browser-widget.h"
+#include "gedit-file-browser-messages.h"
 
 #define WINDOW_DATA_KEY	        	"GeditFileBrowserPluginWindowData"
 #define FILE_BROWSER_BASE_KEY 		"/apps/gedit-2/plugins/filebrowser"
@@ -101,16 +102,13 @@ static gboolean on_confirm_delete_cb     (GeditFileBrowserWidget * widget,
 static gboolean on_confirm_no_trash_cb   (GeditFileBrowserWidget * widget,
                                           GList * files,
                                           GeditWindow * window);
-static void on_end_loading_cb            (GeditFileBrowserStore      * store,
-                                          GtkTreeIter                * iter,
-                                          GeditFileBrowserPluginData * data);
 
 GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE (GeditFileBrowserPlugin, filetree_plugin, 	\
-	gedit_file_browser_enum_and_flag_register_type (module);		\
-	gedit_file_browser_store_register_type         (module);		\
-	gedit_file_bookmarks_store_register_type       (module);		\
-	gedit_file_browser_view_register_type	       (module);		\
-	gedit_file_browser_widget_register_type	       (module);		\
+	gedit_file_browser_enum_and_flag_register_type (type_module);		\
+	gedit_file_browser_store_register_type         (type_module);		\
+	gedit_file_bookmarks_store_register_type       (type_module);		\
+	gedit_file_browser_view_register_type	       (type_module);		\
+	gedit_file_browser_widget_register_type	       (type_module);		\
 )
 
 
@@ -134,17 +132,28 @@ get_plugin_data (GeditWindow * window)
 	return (GeditFileBrowserPluginData *) (g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY));
 }
 
+static void 
+on_end_loading_cb (GeditFileBrowserStore      * store,
+                   GtkTreeIter                * iter,
+                   GeditFileBrowserPluginData * data)
+{
+	/* Disconnect the signal */
+	g_signal_handler_disconnect (store, data->end_loading_handle);
+	data->end_loading_handle = 0;
+	data->auto_root = FALSE;
+}
+
 static void
 prepare_auto_root (GeditFileBrowserPluginData *data)
 {
 	GeditFileBrowserStore *store;
 
 	data->auto_root = TRUE;
-	
+
 	store = gedit_file_browser_widget_get_browser_store (data->tree_widget);
-	
+
 	if (data->end_loading_handle != 0) {
-		g_signal_handler_disconnect(store, data->end_loading_handle);
+		g_signal_handler_disconnect (store, data->end_loading_handle);
 		data->end_loading_handle = 0;
 	}
 
@@ -155,18 +164,15 @@ prepare_auto_root (GeditFileBrowserPluginData *data)
 }
 
 static void 
-restore_default_location (GeditFileBrowserPlugin * plugin, 
-                          GeditFileBrowserPluginData *data)
+restore_default_location (GeditFileBrowserPluginData *data)
 {
 	gchar * root;
 	gchar * virtual_root;
 	gboolean bookmarks;
 	gboolean remote;
 	GConfClient * client;
-	GFile * file = NULL;
 
 	client = gconf_client_get_default ();
-
 	if (!client)
 		return;
 
@@ -192,20 +198,25 @@ restore_default_location (GeditFileBrowserPlugin * plugin,
 	                                NULL);
 
 	if (root != NULL && *root != '\0') {
+		GFile *file;
+
 		file = g_file_new_for_uri (root);
 
-		if (!remote && !g_file_is_native (file)) {
-		} else if (virtual_root != NULL && virtual_root != '\0') {
-			prepare_auto_root(data);
-			gedit_file_browser_widget_set_root_and_virtual_root (data->tree_widget, 
-			                                                     root,
-			                                                     virtual_root);
-		} else {
-			prepare_auto_root(data);
-			gedit_file_browser_widget_set_root (data->tree_widget,
-			                                    root,
-			                                    TRUE);
+		if (remote || g_file_is_native (file)) {
+			if (virtual_root != NULL && *virtual_root != '\0') {
+				prepare_auto_root (data);
+				gedit_file_browser_widget_set_root_and_virtual_root (data->tree_widget, 
+					                                             root,
+					                                             virtual_root);
+			} else {
+				prepare_auto_root (data);
+				gedit_file_browser_widget_set_root (data->tree_widget,
+					                            root,
+					                            TRUE);
+			}
 		}
+
+		g_object_unref (file);
 	}
 
 	g_object_unref (client);
@@ -222,7 +233,6 @@ restore_filter (GeditFileBrowserPluginData * data)
 	gchar *pattern;
 
 	client = gconf_client_get_default ();
-	
 	if (!client)
 		return;
 
@@ -413,39 +423,32 @@ static void
 set_root_from_doc (GeditFileBrowserPluginData * data,
                    GeditDocument * doc)
 {
-	gchar * uri;
-	gchar * root;
-	GFile * parent;
-	GFile * file;
+	GFile *file;
+	GFile *parent;
 
 	if (doc == NULL)
 		return;
 
-	uri = gedit_document_get_uri (doc);
-	if (uri == NULL)
+	file = gedit_document_get_location (doc);
+	if (file == NULL)
 		return;
 
-	file = g_file_new_for_uri (uri);
+	parent = g_file_get_parent (file);
 
-	if (file == NULL) {
-		g_free (uri);
-		return;
+	if (parent != NULL) {
+		gchar * root;
+
+		root = g_file_get_uri (parent);
+
+		gedit_file_browser_widget_set_root (data->tree_widget,
+				                    root,
+				                    TRUE);
+
+		g_object_unref (parent);
+		g_free (root);
 	}
 
-	if ((parent = g_file_get_parent (file))) {
-		g_object_unref (file);
-		file = parent;
-	}
-
-	root = g_file_get_uri (file);
-
-	gedit_file_browser_widget_set_root (data->tree_widget,
-		                            root,
-		                            TRUE);
-
 	g_object_unref (file);
-	g_free (root);
-	g_free (uri);
 }
 
 static void
@@ -685,11 +688,15 @@ impl_activate (GeditPlugin * plugin, GeditWindow * window)
 	GtkWidget * image;
 	GdkPixbuf * pixbuf;
 	GeditFileBrowserStore * store;
+	gchar *data_dir;
 
 	data = g_new (GeditFileBrowserPluginData, 1);
 	data->auto_root = FALSE;
 	data->end_loading_handle = 0;
-	data->tree_widget = GEDIT_FILE_BROWSER_WIDGET (gedit_file_browser_widget_new ());
+	
+	data_dir = gedit_plugin_get_data_dir (plugin);
+	data->tree_widget = GEDIT_FILE_BROWSER_WIDGET (gedit_file_browser_widget_new (data_dir));
+	g_free (data_dir);
 
 	g_signal_connect (data->tree_widget,
 			  "uri-activated",
@@ -721,7 +728,7 @@ impl_activate (GeditPlugin * plugin, GeditWindow * window)
 			  window);			  
 
 	panel = gedit_window_get_side_panel (window);
-	pixbuf = gedit_file_browser_utils_pixbuf_from_theme("file-manager",  
+	pixbuf = gedit_file_browser_utils_pixbuf_from_theme("system-file-manager",  
 	                                                    GTK_ICON_SIZE_MENU);
 	
 	if (pixbuf) {
@@ -741,9 +748,6 @@ impl_activate (GeditPlugin * plugin, GeditWindow * window)
 
 	add_popup_ui (window);
 
-	/* Restore the default location */
-	restore_default_location (GEDIT_FILE_BROWSER_PLUGIN (plugin), data);
-	
 	/* Restore filter options */
 	restore_filter (data);
 	
@@ -776,7 +780,10 @@ impl_activate (GeditPlugin * plugin, GeditWindow * window)
 	                  "tab-added",
 	                  G_CALLBACK (on_tab_added_cb),
 	                  data);
-	                  
+	
+	/* Register messages on the bus */
+	gedit_file_browser_messages_register (window, data->tree_widget);
+
 	impl_updateui (plugin, window);
 }
 
@@ -789,6 +796,9 @@ impl_deactivate (GeditPlugin * plugin, GeditWindow * window)
 
 	data = get_plugin_data (window);
 
+	/* Unregister messages from the bus */
+	gedit_file_browser_messages_unregister (window);
+
 	/* Disconnect signals */
 	g_signal_handlers_disconnect_by_func (window, 
 	                                      G_CALLBACK (on_tab_added_cb),
@@ -899,9 +909,9 @@ on_error_cb (GeditFileBrowserWidget * tree_widget,
 				      GTK_DIALOG_MODAL |
 				      GTK_DIALOG_DESTROY_WITH_PARENT,
 				      GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-				      title);
+				      "%s", title);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
-						  message);
+						  "%s", message);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
@@ -985,7 +995,6 @@ on_rename_cb (GeditFileBrowserStore * store,
 	GFile * oldfile;
 	GFile * newfile;
 	gchar * uri;
-	gchar * relative;
 	
 	/* Find all documents and set its uri to newuri where it matches olduri */
 	app = gedit_app_get_default ();
@@ -1006,30 +1015,33 @@ on_rename_cb (GeditFileBrowserStore * store,
 		if (g_file_equal (docfile, oldfile)) {
 			gedit_document_set_uri (doc, newuri);
 		} else {
+			gchar *relative;
+
 			relative = g_file_get_relative_path (oldfile, docfile);
-			g_object_unref (docfile);
-			g_free (uri);
-		
+
 			if (relative) {
 				/* relative now contains the part in docfile without
 				   the prefix oldfile */
 
+				g_object_unref (docfile);
+				g_free (uri);
+
 				docfile = g_file_get_child (newfile, relative);
 				uri = g_file_get_uri (docfile);
-			
+
 				gedit_document_set_uri (doc, uri);
 			}
-		
+
 			g_free (relative);
 		}
-		
+
 		g_free (uri);
 		g_object_unref (docfile);
 	}
-	
+
 	g_object_unref (oldfile);
 	g_object_unref (newfile);
-	
+
 	g_list_free (documents);
 }
 
@@ -1118,6 +1130,7 @@ on_tab_added_cb (GeditWindow * window,
 {
 	GConfClient *client;
 	gboolean open;
+	gboolean load_default = TRUE;
 
 	client = gconf_client_get_default ();
 
@@ -1130,23 +1143,24 @@ on_tab_added_cb (GeditWindow * window,
 
 	if (open) {
 		GeditDocument *doc;
+		gchar *uri;
 
 		doc = gedit_tab_get_document (tab);
 
-		if (!gedit_document_is_untitled (doc)) {
-			gchar *uri;
+		uri = gedit_document_get_uri (doc);
 
-			uri = gedit_document_get_uri (doc);
-
-			if (gedit_utils_uri_has_file_scheme (uri)) {
-				prepare_auto_root (data);
-				set_root_from_doc (data, doc);
-			}
-
-			g_free (uri);
+		if (uri != NULL && gedit_utils_uri_has_file_scheme (uri)) {
+			prepare_auto_root (data);
+			set_root_from_doc (data, doc);
+			load_default = FALSE;
 		}
+
+		g_free (uri);
 	}
 
+	if (load_default)
+		restore_default_location (data);
+
 	g_object_unref (client);
 
 	/* Disconnect this signal, it's only called once */
@@ -1242,15 +1256,4 @@ on_confirm_delete_cb (GeditFileBrowserWidget *widget,
 	return result;
 }
 
-static void 
-on_end_loading_cb (GeditFileBrowserStore      * store,
-                   GtkTreeIter                * iter,
-                   GeditFileBrowserPluginData * data)
-{
-	/* Disconnect the signal */
-	g_signal_handler_disconnect (store, data->end_loading_handle);
-	data->end_loading_handle = 0;
-	data->auto_root = FALSE;
-}
-
 // ex:ts=8:noet:
