@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-taglist-plugin-parser.c 5677 2007-07-01 16:57:55Z pborelli $
+ * $Id: gedit-taglist-plugin-parser.c 6801 2009-01-03 11:38:19Z pborelli $
  */
 
 /* FIXME: we should rewrite the parser to avoid using DOM */
@@ -34,10 +34,7 @@
 #include <config.h>
 #endif
 
-#include <dirent.h> 
 #include <string.h>
-#include <errno.h>
-
 #include <libxml/parser.h>
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -99,7 +96,7 @@ parse_tag (Tag *tag, xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur)
 		cur = cur->next;
 	}
 
-	if ((tag->begin == NULL) && (tag->end = NULL))
+	if ((tag->begin == NULL) && (tag->end == NULL))
 		return FALSE;
 
 	return TRUE;
@@ -562,35 +559,37 @@ free_taglist (void)
 static TagList * 
 parse_taglist_dir (const gchar *dir)
 {
-	DIR *d;
-	struct dirent *e;
+	GError *error = NULL;
+	GDir *d;
+	const gchar *dirent;
 
 	gedit_debug_message (DEBUG_PLUGINS, "DIR: %s", dir);
 
-	d = opendir (dir);
-	
-	if (d == NULL)
-	{		
-		gedit_debug_message (DEBUG_PLUGINS, "%s", strerror (errno));
+	d = g_dir_open (dir, 0, &error);
+	if (!d)
+	{
+		gedit_debug_message (DEBUG_PLUGINS, "%s", error->message);
+		g_error_free (error);
 		return taglist;
 	}
-	
-	while ((e = readdir (d)) != NULL)
+
+	while ((dirent = g_dir_read_name (d)))
 	{
-		if (strncmp (e->d_name + strlen (e->d_name) - 5, ".tags", 5) == 0 ||
-		    strncmp (e->d_name + strlen (e->d_name) - 8, ".tags.gz", 8) == 0)
+		if (g_str_has_suffix (dirent, ".tags") ||
+		    g_str_has_suffix (dirent, ".tags.gz"))
 		{
-			gchar *tags_file = g_strconcat (dir, e->d_name, NULL);
+			gchar *tags_file = g_build_filename (dir, dirent, NULL);
 			parse_taglist_file (tags_file);
 			g_free (tags_file);
 		}
 	}
-	closedir (d);
+
+	g_dir_close (d);
 
 	return taglist;
 }
 
-TagList* create_taglist (void)
+TagList* create_taglist (const gchar *data_dir)
 {
 	const gchar *home;
 
@@ -603,6 +602,7 @@ TagList* create_taglist (void)
 		return taglist;
 	}
 
+#ifndef G_OS_WIN32
 	/* load user's taglists */
 	home = g_get_home_dir ();
 	if (home != NULL)
@@ -621,9 +621,19 @@ TagList* create_taglist (void)
 		parse_taglist_dir (pdir);
 		g_free (pdir);
 	}
+#else
+	gchar *pdir;
 	
-	/* load system's taglists */	
-	parse_taglist_dir (GEDIT_TAGLIST_DIR);
+	pdir = g_build_filename (g_get_user_config_dir (),
+				 "gedit",
+				 "taglist",
+				 NULL);
+	parse_taglist_dir (pdir);
+	g_free (pdir);
+#endif
+	
+	/* load system's taglists */
+	parse_taglist_dir (data_dir);
 
 	++taglist_ref_count;
 	g_return_val_if_fail (taglist_ref_count == 1, taglist);
