@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-time-plugin.c 6498 2008-09-07 13:50:57Z pborelli $
+ * $Id: gedit-time-plugin.c 6749 2008-12-29 13:41:23Z icq $
  */
 
 /*
@@ -73,7 +73,9 @@ static const gchar *formats[] =
 	"%a %d %b %Y %H:%M:%S",
 	"%d/%m/%Y",
 	"%d/%m/%y",
-	"%D",
+#ifndef G_OS_WIN32
+	"%D", /* This one is not supported on win32 */
+#endif
 	"%A %d %B %Y",
 	"%A %B %d %Y",
 	"%Y-%m-%d",
@@ -741,6 +743,8 @@ static TimeConfigureDialog *
 get_configure_dialog (GeditTimePlugin *plugin)
 {
 	TimeConfigureDialog *dialog = NULL;
+	gchar *data_dir;
+	gchar *ui_file;
 	GtkWidget *content;
 	GtkWidget *viewport;
 	GeditTimePluginPromptType prompt_type;
@@ -775,7 +779,9 @@ get_configure_dialog (GeditTimePlugin *plugin)
 
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
-	ret = gedit_utils_get_ui_objects (GEDIT_UIDIR "time.ui",
+	data_dir = gedit_plugin_get_data_dir (GEDIT_PLUGIN (plugin));
+	ui_file = g_build_filename (data_dir, "time.ui", NULL);
+	ret = gedit_utils_get_ui_objects (ui_file,
 					  root_objects,
 					  &error_widget,
 					  "time_dialog_content", &content,
@@ -788,6 +794,9 @@ get_configure_dialog (GeditTimePlugin *plugin)
 					  "custom_format_example", &dialog->custom_format_example,
 					  NULL);
 
+	g_free (data_dir);
+	g_free (ui_file);
+
 	if (!ret)
 	{
 		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
@@ -917,13 +926,17 @@ get_choose_format_dialog (GtkWindow                 *parent,
 			  GeditTimePlugin           *plugin)
 {
 	ChooseFormatDialog *dialog;
+	gchar *data_dir;
+	gchar *ui_file;
 	GtkWidget *error_widget;
 	gboolean ret;
 	gchar *sf, *cf;
 
 	dialog = g_new0 (ChooseFormatDialog, 1);
 
-	ret = gedit_utils_get_ui_objects (GEDIT_UIDIR "time.ui",
+	data_dir = gedit_plugin_get_data_dir (GEDIT_PLUGIN (plugin));
+	ui_file = g_build_filename (data_dir, "time.ui", NULL);
+	ret = gedit_utils_get_ui_objects (ui_file,
 					  NULL,
 					  &error_widget,
 					  "choose_format_dialog", &dialog->dialog,
@@ -934,6 +947,9 @@ get_choose_format_dialog (GtkWindow                 *parent,
 					  "custom_format_example", &dialog->custom_format_example,
 					  NULL);
 
+	g_free (data_dir);
+	g_free (ui_file);
+
 	if (!ret)
 	{
 		const gchar *err_message;
